常量参数
-----------

.. automodule:: rayvision_houdini.constants
   :members:
   :undoc-members:
   :show-inheritance:

包名(PACKAGE_NAME)
..................

``PACKAGE_NAME`` 设定了日志保存的名称和gitlab 进行自动化部署(CD)打包的包名::

   PACKAGE_NAME = "houdini"

